@@ -16,6 +16,7 @@
 # under the License.
 from __future__ import annotations
 
+import asyncio
 import json
 import time
 from enum import Enum
@@ -211,12 +212,11 @@ class DbtCloudHook(HttpHook):
     async def get_headers_tenants_from_connection(self) -> tuple[dict[str, Any], str]:
         """Get Headers, tenants from the connection details."""
         headers: dict[str, Any] = {}
-        connection: Connection = await sync_to_async(self.get_connection)(self.dbt_cloud_conn_id)
-        tenant = self._get_tenant_domain(connection)
+        tenant = self._get_tenant_domain(self.connection)
         package_name, provider_version = _get_provider_info()
         headers["User-Agent"] = f"{package_name}-v{provider_version}"
         headers["Content-Type"] = "application/json"
-        headers["Authorization"] = f"Token {connection.password}"
+        headers["Authorization"] = f"Token {self.connection.password}"
         return headers, tenant
 
     @provide_account_id
@@ -234,13 +234,14 @@ class DbtCloudHook(HttpHook):
         endpoint = f"{account_id}/runs/{run_id}/"
         headers, tenant = await self.get_headers_tenants_from_connection()
         url, params = self.get_request_url_params(tenant, endpoint, include_related)
-        async with aiohttp.ClientSession(headers=headers) as session:
-            async with session.get(url, params=params) as response:
-                try:
-                    response.raise_for_status()
-                    return await response.json()
-                except ClientResponseError as e:
-                    raise AirflowException(str(e.status) + ":" + e.message)
+        async with aiohttp.ClientSession(headers=headers) as session, session.get(
+            url, params=params
+        ) as response:
+            try:
+                response.raise_for_status()
+                return await response.json()
+            except ClientResponseError as e:
+                raise AirflowException(f"{e.status}:{e.message}")
 
     async def get_job_status(
         self, run_id: int, account_id: int | None = None, include_related: list[str] | None = None
@@ -253,15 +254,10 @@ class DbtCloudHook(HttpHook):
         :param include_related: Optional. List of related fields to pull with the run.
             Valid values are "trigger", "job", "repository", and "environment".
         """
-        try:
-            self.log.info("Getting the status of job run %s.", str(run_id))
-            response = await self.get_job_details(
-                run_id, account_id=account_id, include_related=include_related
-            )
-            job_run_status: int = response["data"]["status"]
-            return job_run_status
-        except Exception as e:
-            raise e
+        self.log.info("Getting the status of job run %s.", run_id)
+        response = await self.get_job_details(run_id, account_id=account_id, include_related=include_related)
+        job_run_status: int = response["data"]["status"]
+        return job_run_status
 
     @cached_property
     def connection(self) -> Connection:
@@ -291,7 +287,7 @@ class DbtCloudHook(HttpHook):
             _paginate_payload = payload.copy() if payload else {}
             _paginate_payload["offset"] = limit
 
-            while not num_current_results >= num_total_results:
+            while num_current_results < num_total_results:
                 response = self.run(endpoint=endpoint, data=_paginate_payload)
                 resp_json = response.json()
                 results.append(response)
@@ -490,14 +486,12 @@ class DbtCloudHook(HttpHook):
         :param account_id: Optional. The ID of a dbt Cloud account.
         :return: The status of a dbt Cloud job run.
         """
-        self.log.info("Getting the status of job run %s.", str(run_id))
+        self.log.info("Getting the status of job run %s.", run_id)
 
         job_run = self.get_job_run(account_id=account_id, run_id=run_id)
         job_run_status = job_run.json()["data"]["status"]
 
-        self.log.info(
-            "Current status of job run %s: %s", str(run_id), DbtCloudJobRunStatus(job_run_status).name
-        )
+        self.log.info("Current status of job run %s: %s", run_id, DbtCloudJobRunStatus(job_run_status).name)
 
         return job_run_status
 
@@ -601,6 +595,43 @@ class DbtCloudHook(HttpHook):
             endpoint=f"{account_id}/runs/{run_id}/artifacts/{path}", payload={"step": step}
         )
 
+    @fallback_to_default_account
+    async def get_job_run_artifacts_concurrently(
+        self,
+        run_id: int,
+        artifacts: list[str],
+        account_id: int | None = None,
+        step: int | None = None,
+    ):
+        """
+        Retrieves a list of chosen artifact files generated for a step in completed run of a dbt Cloud job.
+
+        By default, this returns artifacts from the last step in the run.
+        This takes advantage of the asynchronous calls to speed up the retrieval.
+
+        :param run_id: The ID of a dbt Cloud job run.
+        :param step: The index of the Step in the Run to query for artifacts. The first step in the
+            run has the index 1. If the step parameter is omitted, artifacts for the last step in the run will
+            be returned.
+        :param path: The file path related to the artifact file. Paths are rooted at the target/ directory.
+            Use "manifest.json", "catalog.json", or "run_results.json" to download dbt-generated artifacts
+            for the run.
+        :param account_id: Optional. The ID of a dbt Cloud account.
+
+        :return: The request response.
+        """
+        tasks = {
+            artifact: sync_to_async(self.get_job_run_artifact)(
+                run_id,
+                path=artifact,
+                account_id=account_id,
+                step=step,
+            )
+            for artifact in artifacts
+        }
+        results = await asyncio.gather(*tasks.values())
+        return {filename: result.json() for filename, result in zip(tasks.keys(), results)}
+
     def test_connection(self) -> tuple[bool, str]:
         """Test dbt Cloud connection."""
         try:
